package cd.casic.ci.api;

import cd.casic.ci.process.process.service.sftpFile.SftpFileService;
import cd.casic.ci.process.properties.TargetFileUploadProperties;
import cd.casic.framework.commons.pojo.CommonResult;
import jakarta.annotation.Resource;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.IOException;
import java.util.List;

/**
 * @author HopeLi
 * @version v1.0
 * @ClassName SftpFileController
 * @Date: 2025/7/1 9:03
 * @Description:
 */
@RestController
@RequestMapping("/sftpFile")
public class SftpFileController {

    @Resource
    private SftpFileService sftpFileService;

    @Resource
    private TargetFileUploadProperties fileUploadProperties;

    @PostMapping("/upload")
    public CommonResult<String> uploadFile(
            @RequestParam String remoteDir,
            @RequestParam String remoteFileName,
            @RequestParam MultipartFile file) {

        String localFilePath = saveTempFile(file);
        sftpFileService.uploadFile(
                fileUploadProperties.getRemoteHost(),
                fileUploadProperties.getRemotePort(),
                fileUploadProperties.getUsername(),
                fileUploadProperties.getPassword(),
                fileUploadProperties.getSshKeyPath(),
                localFilePath, remoteDir, remoteFileName);

        return CommonResult.success("文件上传成功");
    }

    @GetMapping("/download")
    public void downloadFile(
            @RequestParam String remoteFilePath,
            HttpServletResponse response) {

        sftpFileService.downloadFile(
                fileUploadProperties.getRemoteHost(),
                fileUploadProperties.getRemotePort(),
                fileUploadProperties.getUsername(),
                fileUploadProperties.getPassword(),
                fileUploadProperties.getSshKeyPath(),
                remoteFilePath, response);
    }

    @PostMapping("/download/zip")
    public void downloadFilesAsZip(
            @RequestBody List<String> remoteFilePaths,
            @RequestParam String zipFileName,
            HttpServletResponse response) {

        sftpFileService.downloadFilesAsZip(
                fileUploadProperties.getRemoteHost(),
                fileUploadProperties.getRemotePort(),
                fileUploadProperties.getUsername(),
                fileUploadProperties.getPassword(),
                fileUploadProperties.getSshKeyPath(),
                remoteFilePaths, zipFileName, response);
    }

    private String saveTempFile(MultipartFile file) {
        try {
            File tempFile = File.createTempFile("upload-", ".tmp");
            file.transferTo(tempFile);
            return tempFile.getAbsolutePath();
        } catch (IOException e) {
            throw new RuntimeException("保存临时文件失败", e);
        }
    }
}
